@@ -1,10 +1,12 @@
 {% include "Shared/cpp/header_comments" %}
 {% include "Shared/cpp/includes" %}
+{% include "Shared/cpp/lookup_tables" %}
 {% include "Shared/cpp/UseCellMLDefaultStimulus" %}
 {% include "Shared/cpp/GetIntracellularCalciumConcentration" %}
 {% include "RL/cpp/constructor_declaration" %}
 {% include "Shared/cpp/constructor_body" %}
 {% include "Shared/cpp/destructor" %}
+{% include "Shared/cpp/GetLookupTableCollection" %}
 {% include "Shared/cpp/VerifyStateVariables" %}
 {% include "Shared/cpp/GetIIonic" %}
 {% include "GRL/cpp/UpdateTransmembranePotential" %}
